@@ -6,7 +6,7 @@ class Common:
     Sender          = _config.__Sender__
     APIKey          = _config.__APIKey__
     APIVersion      = _config.__APIVersion__
-    APIURL          = _config.__APIURL__ + "/set/"
+    APIURL          = _config.__APIURL__
     APIHeaders      = _config.__APIHeaders__
 
     MessageID       = ""
@@ -15,6 +15,16 @@ class Common:
     def __init__(self,kwargs):
         self.SetArgs(kwargs)
 
+    """ Destructor """
+    def __del__(self):
+        self.Sender          = ""
+        self.APIKey          = ""
+        self.APIVersion      = ""
+        self.APIURL          = ""
+        self.APIHeaders      = ""
+
+        self.MessageID       = ""
+
     """ Set Args """
     def SetArgs(self, kwargs):
 
